@@ -22,54 +22,53 @@
 # @return \item{comp}{matrix of size (number of statistical units * number of components) having the components as column vectors}
 # @return \item{compr}{matrix of size (number of statistical units * number of components) having the standardized components as column vectors}
 # @return \item{ds}{the final value of the regularization degree}
-kComponents <- function(X,Y,AX,K,family,size=NULL,offset=NULL,crit,method)
-{
-  n<-dim(X)[1]
-  #p<-dim(X)[2]
-  q<-dim(Y)[2]
-  if (is.null(q)) q<-1
-  # on stocke la matrice X et on la centre-reduit
-  #Xorig<-X
+kComponents <- function(X, Y, AX, K, family, size=NULL, offset=NULL, crit, method) {
+  n <- dim(X)[1]
+  
   F <- NULL
-  out <- oneComponent(X,Y,AX,F=F,family=family,size=size,
-                      offset=offset,crit=crit,method=method)
+  out <- oneComponent(X, Y, AX, F=F, family=family, size=size,
+    offset=offset, crit=crit, method=method)
   if(is.logical(out))
-    custom_stop("convergence_failed")
-
+    custom_stop("convergence_failed", "k=1")
+  
   u <- out$u
-  f <- X%*%u
+  f <- X %*% u
   F <- f
-  Fr <- f/sqrt(c(crossprod(f,f))/n)
-
-  #Composantes suivantes si K>1
+  Fr <- f/sqrt(c(crossprod(f, f))/n)
+  
+  # next component if K>1
   if(K>1) {
-    #keep_tol <- crit$tol
+    
     for (k in 2:K) {
-      #crit$tol <- keep_tol
-      FAX <- cbind(F,AX)
-      out <- oneComponent(X,Y,FAX,F,family=family,size=size,
-                          offset=offset,crit=crit,method=method)
+      
+      FAX <- cbind(F, AX)
+      out <- oneComponent(X, Y, FAX, F, family=family, size=size,
+        offset=offset, crit=crit, method=method)
       if(is.logical(out))
-        custom_stop("convergence_failed")
-
-      f <- X%*%out$u
-      Fr <- cbind(Fr,f/sqrt(c(crossprod(f,f))/n))
-      u <- cbind(u,out$u)
-      F <- cbind(F,f)
+        custom_stop("convergence_failed", "k=", k)
+      
+      f <- X %*% out$u
+      Fr <- cbind(Fr, f/sqrt(c(crossprod(f, f))/n))
+      u <- cbind(u, out$u)
+      F <- cbind(F, f)
     }
   }
+  
   u <- as.matrix(u)
-  colnames(u) <- paste("u",1:ncol(u),sep="")
-  colnames(F) <- paste("sc",1:ncol(F),sep="")
-  colnames(Fr) <- paste("sc",1:ncol(Fr),sep="")
+  colnames(u) <- paste0("u", 1:ncol(u))
+  colnames(F) <- paste0("sc", 1:ncol(F))
+  colnames(Fr) <- paste0("sc", 1:ncol(Fr))
+  
   gamma <- out$gamma
-  if(is.null(AX)){
-    rownames(gamma) <- c("(intercept)",colnames(Fr))
-  }else{
-    gamma <- gamma[c(1:K,(nrow(gamma)),(K+1):(nrow(gamma)-1)),,drop=FALSE]
-    rownames(gamma) <- c("(intercept)",colnames(Fr),colnames(AX))
+  
+  if(is.null(AX)) {
+    rownames(gamma) <- c("(intercept)", colnames(Fr))
+  } else {
+    gamma <- gamma[c(1:K, (nrow(gamma)), (K+1):(nrow(gamma)-1)), , drop=FALSE]
+    rownames(gamma) <- c("(intercept)", colnames(Fr), colnames(AX))
   }
-  return(list(u=u,F=F,Fr=Fr,gamma=gamma))
+  
+  return(list(u=u, F=F, Fr=Fr, gamma=gamma))
 }
 
 
