@@ -1,19 +1,15 @@
-if(getRversion()>="2.15.1") {
-# remove warnings due to ggplot2 syntax strangeness
-  utils::globalVariables(c("comp","y","label","angle","hjust"))
-}
-
 #' SCGLR generic plot
 #' @export
+#' @method plot SCGLR
 #' @importFrom stats cor aggregate
 #' @importFrom grid gpar circleGrob grid.newpage pushViewport viewport grid.layout
-#' @method plot SCGLR
 #' @description SCGLR generic plot
 #' @param x an object from SCGLR class.
 #' @param \dots optional arguments (see \link{customize}).
 #' @param style named list of values used to customize the plot (see \link{customize})
-#' @param plane a size-2 vector (or comma separated string) indicating which components are plotted (eg: c(1,2) or "1,2").
-#' @return an object of class \code{\link{ggplot}}.
+#' @param plane a size-2 vector (or string with separator) indicating which components 
+#' are plotted (eg: c(1,2) or "1,2" or "1/2").
+#' @return an object of class \code{ggplot}.
 #' @examples \dontrun{
 #' library(SCGLR)
 #'
@@ -52,12 +48,12 @@ if(getRversion()>="2.15.1") {
 #' }
 plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
   data <- x
-  if (class(data) != "SCGLR")
+  if (!inherits(data, "SCGLR"))
     stop("This plot function need an SCGLR result")
-
+  
   if (dim(data$compr)[2] < 2)
     stop("At least two axes are needed for this kind of plot!")
-
+  
   # customize from remaining arguments
   dots <- list(...)
   # merged with style argument
@@ -109,16 +105,16 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
     key <- cust(key, def)
     !is.null(key) && (!is.logical(key) || key)
   }
-
+  
   labels.offset <- cust("labels.offset",0.01)
   labels.auto <- cust("labels.auto",TRUE)
   labels.size <- cust("labels.size",1)
-
+  
   # process plane
   if(is.character(plane)) {
-    plane <- as.integer(trim(unlist(strsplit(plane,","))))
+    plane <- as.integer(split(plane))
   }
-
+  
   # sanity checking
   if(length(plane) != 2 ) {
     stop("Plane should have two components!")
@@ -126,10 +122,10 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
   if((min(plane)<1) || (max(plane)>ncol(data$compr))) {
     stop("Invalid components for plane!")
   }
-
+  
   # plan
   axis_names <- colnames(data$compr)[plane]
-
+  
   # check factor
   factor <- cust("factor",NULL)
   if(!is.null(factor) && (is.character(factor) || factor)) {
@@ -143,17 +139,18 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
         stop("Invalid factor!")
     }
   }
-
+  
   # inertia
   inertia <- data$inertia[plane]
-
+  
   # layers
   covariates <- has_cust("covariates",TRUE)
   predictors <- has_cust("predictors",FALSE)
   observations <- has_cust("observations",FALSE)
-
+  
   # build base plot
-  p <- qplot((-1:1)*cust("expand",1.0), (-1:1)*cust("expand",1.0), geom="blank")+
+  p <- ggplot()+
+    geom_blank(aes((-1:1)*cust("expand",1.0), (-1:1)*cust("expand",1.0)))+
     coord_fixed()+
     # thicker x unit arrow
     xlab(paste(axis_names[1],"(",round(100*inertia[1],2),"%)")) +
@@ -163,10 +160,11 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
     ylab(paste(axis_names[2],"(",round(100*inertia[2],2),"%)")) +
     geom_vline(xintercept=0)+
     geom_segment(aes(y=-1.1,yend=1.1,x=0,xend=0),size=1,arrow=arrow(length=unit(0.02,"npc")))
-
+  
   # plot title
   if(has_cust("title", FALSE)) {
-    p <- p + ggtitle(cust("title"))
+    if(is.character(cust("title")))
+      p <- p + ggtitle(cust("title"))
   } else {
     if(observations) {
       if(covariates||predictors) {
@@ -182,32 +180,32 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
       }
     }
   }
-
+  
   # add unit circle
   if(covariates||predictors)
     p <- p + annotation_custom(circleGrob(r=0.5,gp=gpar(fill=NA)),-1,1,-1,1)
-
+  
   # add threshold circle
   if((covariates||predictors)&&has_cust("threshold"))
     p <- p + annotation_custom(circleGrob(r=0.5*cust("threshold"),gp=gpar(fill=NA,lty="dashed")),-1,1,-1,1)
-
+  
   # add observations
   if(observations) {
     obs <- as.data.frame(data$compr[,plane])
     names(obs) <- c("x","y")
-
+    
     # colored according to factor ?
     if(!is.null(factor)&&(cust("observations.factor",FALSE))) {
       obs <- cbind(obs,data$xFactors[factor])
       p <- p + geom_point(
-        aes_string(x="x",y="y",color=factor),
+        aes(x=.data$x,y=.data$y,color=.data[[factor]]),
         data=obs,
         size=cust("observations.size",1),
         alpha=cust("observations.alpha",1)
       )
     } else {
       p <- p + geom_point(
-        aes(x=x, y=y),
+        aes(x=.data$x, y=.data$y),
         data=obs,
         size=cust("observations.size",1),
         color=cust("observations.color","black"),
@@ -215,7 +213,7 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
       )
     }
   }
-
+  
   # add linear predictor arrows
   if(predictors) {
     predictors <- cust("predictors")
@@ -234,7 +232,7 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
       co$labels.alpha <- cust("predictors.labels.alpha",co$alpha)
       co$labels.size <- cust("predictors.labels.size",4*labels.size)
     }
-
+    
     # adjust label position
     co$angle <- atan2(co$y,co$x)*180/pi
     co$hjust <- ifelse(abs(co$angle)>90,1,0)
@@ -243,23 +241,23 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
     } else {
       co$angle <- 0
     }
-
+    
     # filter according to user's will
     if(is.character(predictors)) {
-      co <- co[co$label %in% predictors,]
+      co <- co[co$label %in% split(predictors),]
     }
-
+    
     # filter according to given threshold
     if(cust("threshold",FALSE)>0)
       co <- co[co$norm>cust("threshold"),]
-
+    
     if(nrow(co)==0) {
       warning("No predictors with correlation higher than threshold value ",cust("threshold"),"!")
     } else {
       # draw arrows ?
       if(cust("predictors.arrows",TRUE)) {
         p <- p + geom_segment(
-          aes(x=0,y=0,xend=x,yend=y),
+          aes(x=0,y=0,xend=.data$x,yend=.data$y),
           data=co,
           color=co$arrows.color,
           alpha=co$arrows.alpha,
@@ -270,11 +268,17 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
         co$hjust <- 0.5
         co$angle <- 0
       }
-
+      
       # draw labels ?
       if(cust("predictors.labels",TRUE)) {
         p <- p + geom_text(
-          aes(x=x*(1+labels.offset/norm),y=y*(1+labels.offset/norm),label=label,angle=angle,hjust=hjust),
+          aes(
+            x=.data$x*(1+labels.offset/norm),
+            y=.data$y*(1+labels.offset/norm),
+            label=.data$label,
+            angle=.data$angle,
+            hjust=.data$hjust
+          ),
           data=co,
           color=co$labels.color,
           alpha=co$labels.alpha,
@@ -283,7 +287,7 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
       }
     }
   }
-
+  
   # add co-variate arrows
   if(covariates) {
     covariates <- cust("covariates")
@@ -302,7 +306,7 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
       co$labels.alpha <- cust("covariates.labels.alpha",co$alpha)
       co$labels.size <- cust("covariates.labels.size",4*labels.size)
     }
-
+    
     # adjust label position
     co$angle <- atan2(co$y,co$x)*180/pi
     co$hjust <- ifelse(abs(co$angle)>90,1,0)
@@ -311,23 +315,23 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
     } else {
       co$angle <- 0
     }
-
+    
     # filter according to users's will
     if(is.character(covariates)) {
-      co <- co[co$label %in% covariates,]
+      co <- co[co$label %in% split(covariates),]
     }
-
+    
     # filter according to given threshold
     if(cust("threshold",FALSE)>0)
       co <- co[co$norm>cust("threshold"),]
-
+    
     if(nrow(co)==0) {
       warning("No correlation higher than threshold value ",cust("threshold"),"!")
     } else {
       # draw arrows ?
       if(cust("covariates.arrows",TRUE)) {
         p <- p + geom_segment(
-          aes(x=0,y=0,xend=x,yend=y),
+          aes(x=0,y=0,xend=.data$x,yend=.data$y),
           data=co,
           color=co$arrows.color,
           alpha=co$arrows.alpha,
@@ -338,11 +342,17 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
         co$hjust <- 0.5
         co$angle <- 0
       }
-
+      
       # draw labels ?
       if(cust("covariates.labels",TRUE)) {
         p <- p + geom_text(
-          aes(x=x*(1+labels.offset/norm),y=y*(1+labels.offset/norm),label=label,angle=angle,hjust=hjust),
+          aes(
+            x=.data$x*(1+labels.offset/norm),
+            y=.data$y*(1+labels.offset/norm),
+            label=.data$label,
+            angle=.data$angle,
+            hjust=.data$hjust
+          ),
           data=co,
           color=co$labels.color,
           size=co$labels.size,
@@ -351,67 +361,66 @@ plot.SCGLR <- function(x, ..., style=getOption("plot.SCGLR"), plane=c(1, 2)) {
       }
     }
   }
-
+  
   # add factors
   if(!is.null(factor)) {
     bary <- aggregate(data$compr[,plane],data$xFactors[factor],mean)
     names(bary) <- c(factor,"x","y")
-
+    
     # draw points ?
     if(cust("factor.points",TRUE)) {
       p <- p + geom_point(
-        aes_string(x="x",y="y",color=factor),
+        aes(x=.data$x,y=.data$y,color=.data[[factor]]),
         data=bary,
         size=cust("factor.points.size",4),
         shape=cust("factor.points.shape",13)
-        )
+      )
     }
-
+    
     # draw labels ?
     if(cust("factor.labels",TRUE)) {
       p <- p + geom_text(
-        aes_string(x="x",y="y",label=factor),
+        aes(x=.data$x,y=.data$y,label=.data[[factor]]),
         data=bary,
         color=cust("factor.labels.color","black"),
         size=cust("factor.labels.size",4*labels.size)
-        )
+      )
     }
   }
-
+  
   # return plot
   p
 }
 
-#' @title Barplot of percent of overall X variance captured by component
-#' @export
-#' @method barplot SCGLR
-#' @description Barplot of percent of overall X variance captured by component
-#' @param height object of class 'SCGLR', usually a result of running \code{\link{scglr}}.
-#' @param \dots optional arguments.
-#' @return an object of class ggplot.
-#' @seealso For barplot application see examples in \code{\link{plot.SCGLR}}.
-#' @keywords internal
-barplot.SCGLR <- function(height, ...) {
-  .Deprecated("screeplot")
-  screeplot.SCGLR(height, ...)
-}
-
 #' @title Screeplot of percent of overall X variance captured by component
 #' @export
 #' @method screeplot SCGLR
 #' @description Screeplot of percent of overall X variance captured by component
 #' @param x object of class 'SCGLR', usually a result of running \code{\link{scglr}}.
 #' @param \dots optional arguments.
-#' @return an object of class ggplot.
+#' @return an object of class \code{ggplot}.
 #' @seealso For screeplot application see examples in \code{\link{plot.SCGLR}}.
 screeplot.SCGLR <- function(x, ...) {
-  inertia <- data.frame(inertia=x$inertia,comp=1:length(x$inertia))
+  inertia <- data.frame(inertia=x$inertia,comp=names(x$inertia))
   ggplot(inertia)+
-    geom_col(aes(x=comp,y=inertia))+
-    scale_x_discrete(labels=names(x$inertia),limits=1:length(inertia$comp))+
+    geom_col(aes(x=.data$comp,y=.data$inertia))+
     labs(x="Components", y="Inertia", title="Inertia per component\n", ...)
 }
 
+#' @title Barplot of percent of overall X variance captured by component
+#' @export
+#' @method barplot SCGLR
+#' @description Barplot of percent of overall X variance captured by component
+#' @param height object of class 'SCGLR', usually a result of running \code{\link{scglr}}.
+#' @param \dots optional arguments.
+#' @return an object of class \code{ggplot}.
+#' @seealso For barplot application see examples in \code{\link{plot.SCGLR}}.
+#' @keywords internal
+barplot.SCGLR <- function(height, ...) {
+  .Deprecated("screeplot")
+  screeplot.SCGLR(height, ...)
+}
+
 #' @title Pairwise scglr plot on components
 #' @export
 #' @method pairs SCGLR
@@ -421,17 +430,17 @@ screeplot.SCGLR <- function(x, ...) {
 #' @param nrow number of rows of the grid layout.
 #' @param ncol number of columns of the grid layout.
 #' @param components vector of integers selecting components to plot (default is all components).
-# @return an object of class ggplot.
+#' @return an object of class \code{ggplot}.
 #' @seealso For pairs application see examples in \code{\link{plot.SCGLR}}
 pairs.SCGLR <- function(x, ..., nrow=NULL, ncol=NULL, components=NULL) {
   prm <- list(...)
-
+  
   nr <- nrow
   nc <- ncol
-
+  
   prm["x"] <- list(x)
   prm[["components"]] <- NULL
-
+  
   # pairs of components
   if(is.null(components)) {
     ncomp <- ncol(x$compr)
@@ -444,22 +453,19 @@ pairs.SCGLR <- function(x, ..., nrow=NULL, ncol=NULL, components=NULL) {
   }
   # build pairs
   cmp_pairs <- combn(ncomp, 2, simplify=FALSE)
-
+  
   # build plot list
   one_plot <- function(cmp_pair) {
+    # TODO forward ... minus plane and title to plot.SCGLR
     do.call("plot.SCGLR", c(prm, plane=list(cmp_pair),title=paste(cmp_pair,collapse = "/")))
   }
   plots <- lapply(cmp_pairs, one_plot)
-
+  
   # arrange them in a grid
   if(is.null(nc) & is.null(nr)) {
     nr <- as.integer(sqrt(length(plots)))
   }
-#  if(require("gridExtra",quietly = TRUE)) {
-#    do.call("arrangeGrob", c(plots, nrow=nr, ncol=nc,main="toto"))
-#  } else {
-    do.call("arrange", c(plots, nrow=nr, ncol=nc))
-#  }
+  do.call("arrange", c(plots, nrow=nr, ncol=nc))
 }
 
 ## equivalent du par pour les ggplot2
@@ -467,9 +473,9 @@ vp.layout <- function(x, y) viewport(layout.pos.row=x, layout.pos.col=y)
 arrange <- function(..., nrow=NULL, ncol=NULL, as.table=FALSE) {
   dots <- list(...)
   n <- length(dots)
-  if(is.null(nrow) & is.null(ncol)) { nrow = floor(n/2) ; ncol = ceiling(n/nrow)}
-  if(is.null(nrow)) { nrow = ceiling(n/ncol)}
-  if(is.null(ncol)) { ncol = ceiling(n/nrow)}
+  if(is.null(nrow) & is.null(ncol)) { nrow <- floor(n/2) ; ncol <- ceiling(n/nrow)}
+  if(is.null(nrow)) { nrow <- ceiling(n/ncol)}
+  if(is.null(ncol)) { ncol <- ceiling(n/nrow)}
   ## NOTE see n2mfrow in grDevices for possible alternative
   grid.newpage()
   pushViewport(viewport(layout=grid.layout(nrow,ncol) ) )
@@ -487,26 +493,13 @@ arrange <- function(..., nrow=NULL, ncol=NULL, as.table=FALSE) {
   invisible(NULL)
 }
 
-#' @title Barplot of percent of overall X variance captured by component
-#' @export
-#' @method barplot SCGLRTHM
-#' @description Barplot of percent of overall X variance captured by component by theme
-#' @param height object of class 'SCGLRTHM', usually a result of running \code{\link{theme}}.
-#' @param \dots optional arguments.
-#' @return an object of class ggplot.
-#' @keywords internal
-barplot.SCGLRTHM <- function(height, ...) {
-  .Deprecated("screeplot.SCGLRTHM")
-  screeplot.SCGLRTHM(height, ...)
-}
-
 #' @title Screeplot of percent of overall X variance captured by component
 #' @export
 #' @method screeplot SCGLRTHM
 #' @description Screeplot of percent of overall X variance captured by component by theme
-#' @param x object of class 'SCGLRTHM', usually a result of running \code{\link{theme}}.
+#' @param x object of class 'SCGLRTHM', usually a result of running \code{\link{scglrTheme}}.
 #' @param \dots optional arguments.
-#' @return an object of class ggplot.
+#' @return an object of class \code{ggplot}.
 screeplot.SCGLRTHM <- function(x, ...) {
   plots <- lapply(x$themes, function(t) 
     screeplot.SCGLR(t,...)+
@@ -515,13 +508,26 @@ screeplot.SCGLRTHM <- function(x, ...) {
   do.call(arrange, plots)
 }
 
+#' @title Barplot of percent of overall X variance captured by component
+#' @export
+#' @method barplot SCGLRTHM
+#' @description Barplot of percent of overall X variance captured by component by theme
+#' @param height object of class 'SCGLRTHM', usually a result of running \code{\link{scglrTheme}}.
+#' @param \dots optional arguments.
+#' @return an object of class \code{ggplot}.
+#' @keywords internal
+barplot.SCGLRTHM <- function(height, ...) {
+  .Deprecated("screeplot.SCGLRTHM")
+  screeplot.SCGLRTHM(height, ...)
+}
+
 #' SCGLRTHM generic plot
 #' @export
 #' @method plot SCGLRTHM
 #' @description SCGLR generic plot for themes
-#' @param x an object from SCGLRTHM class.
+#' @param x object of class 'SCGLRTHM', usually a result of running \code{\link{scglrTheme}}.
 #' @param \dots see SCGLR plot method
-#' @return an object of class \code{\link{ggplot}}.
+#' @return an object of class \code{ggplot}.
 plot.SCGLRTHM <- function(x, ...) {
   plots <- lapply(x$themes, function(t) 
     plot.SCGLR(t,...)+
